@@ -2,6 +2,7 @@ from __future__ import division
 import math
 import time
 import os.path
+import sqlite3
 
 from collections import deque
 from pyglet import image
@@ -902,13 +903,52 @@ class World:
                 for z in range(zmin, zmax+1):
                     self.setBlock(x,y,z, blocktype)
 
-    def player_position(self):
-        return self.window.position
+    def player_position(self, as_int=False):
+        "Return the current position of the player."
+        x,y,z = self.window.position
+        if as_int:
+            return int(x), int(y), int(z)
+        else:
+            return x,y,z
 
     def run(self):
         setup()
         pyglet.app.run()
 
+class PersistentWorld(World):
+    def __init__(self, name="PyBlockWorld (persistent)", filename="blockworld.sqlite"):
+        super().__init__(name)
+        self.db = sqlite3.connect(filename)
+        self._init_db()
+        self._init_world()
+
+    def _init_db(self):
+        self.__exec_db("CREATE table IF NOT EXISTS blocks (x float, y float, z float, type test)")
+
+    def _init_world(self):
+        c = self.__exec_db("SELECT x,y,z,type FROM blocks")
+        for x,y,z,bt in c:
+            print("adding", x,y,z)
+            self.setBlock(x,y,z,bt, add_to_db=False)
+
+    def __exec_db(self, sql, args=[], commit=True):
+        c = self.db.cursor()
+        c.execute(sql, args)
+
+        if commit:
+            self.db.commit()
+
+        return c
+        
+    def setBlock(self, x, y, z, blocktype, add_to_db=True):
+        super().setBlock(x, y, z, blocktype)
+        if add_to_db:
+            self.__exec_db(
+                "INSERT INTO blocks (x,y,z,type) VALUES (?,?,?,?)",
+                (x,y,z,blocktype)
+            )
+
+
 def setup_fog():
     """ Configure the OpenGL fog properties.
 
@@ -947,10 +987,23 @@ def setup():
     setup_fog()
 
 def main():
+    #demo1()
+    #demo2()
     w = World("DEMO")
     w.run()
 
-def demo():
+def demo2():
+    from pyblockworld import PersistentWorld
+    pw = PersistentWorld(filename="blockworld.sqlite")
+    
+    def b_key_pressed(world):
+        x,y,z = world.player_position()
+        world.setBlock(x,y,z, "default:brick")
+
+    pw.build_key_pressed = b_key_pressed
+    pw.run()
+
+def demo1():
     from pyblockworld import World
 
     #
@@ -959,7 +1012,7 @@ def demo():
     
     # Eine Funktion, die beim Drücken der B-Taste aufgerufen werden soll
     def b_key_pressed(world:World):
-        print("B pressed. Player at", world.player_position())
+        print("B pressed. Player at", world.player_position(True))
         
     # Erstellen einer neuen Welt
     world = World()
